@@ -152,17 +152,16 @@ def handle_trigger(
     new_trigger = is_new_trigger(glueclient, trigger_name)
 
     schedule = None if trigger_type != "SCHEDULED" else trigger_definition["Schedule"]
-    predicate = (
-        {} if trigger_type != "CONDITIONAL" else trigger_definition["Predicate"]
-    )
+    predicate = {} if trigger_type != "CONDITIONAL" else trigger_definition["Predicate"]
     event_batching = (
-        {
-            "BatchSize": 1
-        }
+        {"BatchSize": 1}
         if trigger_type != "EVENT"
         else trigger_definition["EventBatchingCondition"]
     )
 
+    actions = [{"JobName": job_name}] if 'Actions' not in trigger_definition else trigger_definition['Actions']
+    trigger_definition['Actions'] = actions
+
     if new_trigger:
         response = glueclient.create_trigger(
             Name=trigger_name,
